@@ -84,56 +84,32 @@ function(object,p) {
     p.dup <- duplicated(p)
     q[p<=0] <- mn
     q[p>=1] <- mx
+    qd.hize <- 200
+    qd <- gauss.quad(2*qd.hize,c(mn,mx))
+    d.qd <- dssden(object,qd$pt)
+    gap <- diff(qd$pt)
+    g.wk <- gap[qd.hize]/2
+    for (i in 1:(qd.hize-2)) g.wk <- c(g.wk,gap[qd.hize+i]-g.wk[i])
+    g.wk <- 2*g.wk
+    g.wk <- c(g.wk,(mx-mn)/2-sum(g.wk))
+    gap[qd.hize:1] <- gap[qd.hize+(1:qd.hize)] <- g.wk
+    brk <- cumsum(c(mn,gap))
+    p.wk <- cumsum(d.qd*qd$wt)
     kk <- (1:length(p))[p>0&p<1]
-    q.wk <- object$quad$pt[,1]
-    p.wk <- cumsum(object$quad$wt*dssden(object,q.wk))
     for (i in kk) {
         if (p.dup[i]) {
             q[i] <- q.dup
             next
         }
-        j <- which.min(abs(p[i]-p.wk))
-        q0 <- q.wk[j]
-        p0 <- pssden(object,q0)
-        if (p0==p[i]) {
-            q[i] <- q0
-            next
-        }
-        if (p0<p[i]) {
-            q.l <- q0
-            p.l <- p0
-            while (p0<p[i]) {
-                j <- j+1
-                q0 <- ifelse(is.null(q.wk[j]),mx,q.wk[j])
-                p0 <- pssden(object,q0)
-            }
-            q.u <- q0
-            p.u <- p0
+        ind <- (1:(2*qd.hize))[p.wk<p[i]]
+        if (!length(ind)) {
+            wk <- mn+p[i]/(d.qd[1]*qd$wt[1])*gap[1]
         }
         else {
-            q.u <- q0
-            p.u <- p0
-            while (p0>p[i]) {
-                j <- j-1
-                q0 <- ifelse(is.null(q.wk[j]),mn,q.wk[j])
-                p0 <- pssden(object,q0)
-            }
-            q.l <- q0
-            p.l <- p0
+            id.mx <- max(ind)
+            wk <- brk[id.mx+1]+(p[i]-p.wk[id.mx])/(d.qd[id.mx+1]*qd$wt[id.mx+1])*gap[id.mx+1]
         }
-        while (abs(p0-p[i])>1e-10) {
-            q0 <- q.l+(p[i]-p.l)/(p.u-p.l)*(q.u-q.l)
-            p0 <- pssden(object,q0)
-            if (p0>p[i]) {
-                q.u <- q0
-                p.u <- p0
-            }
-            else {
-                q.l <- q0
-                p.l <- p0
-            }
-        }
-        q[i] <- q.dup <- q0
+        q[i] <- q.dup <- wk
     }
     q[order.p]
 }
